Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(4)

Unified Diff: src/accessors.cc

Issue 177683002: Mode clean-up pt 1: rename classic/non-strict mode to sloppy mode (Closed) Base URL: https://v8.googlecode.com/svn/branches/bleeding_edge
Patch Set: Created 6 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/a64/lithium-codegen-a64.cc ('k') | src/api.cc » ('j') | src/globals.h » ('J')
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/accessors.cc
diff --git a/src/accessors.cc b/src/accessors.cc
index 47b0a856332e24cec0b4ff7e8ab0666d20ca9dc2..daa865400bc2d61dc1ae2bd8de7b8897fadc3e90 100644
--- a/src/accessors.cc
+++ b/src/accessors.cc
@@ -911,10 +911,10 @@ MaybeObject* Accessors::FunctionGetCaller(Isolate* isolate,
if (caller->shared()->bound()) {
return isolate->heap()->null_value();
}
// Censor if the caller is not a classic mode function.
// Change from ES5, which used to throw, see:
// https://bugs.ecmascript.org/show_bug.cgi?id=310
- if (!caller->shared()->is_classic_mode()) {
+ if (!caller->shared()->is_sloppy_mode()) {
return isolate->heap()->null_value();
}
« no previous file with comments | « src/a64/lithium-codegen-a64.cc ('k') | src/api.cc » ('j') | src/globals.h » ('J')
@@ -911,10 +911,10 @@ MaybeObject* Accessors::FunctionGetCaller(Isolate* isolate,
return isolate->heap()->null_value();
}
- // Censor if the caller is not a classic mode function.
+ // Censor if the caller is not a sloppy mode function.
// Change from ES5, which used to throw, see:
// https://bugs.ecmascript.org/show_bug.cgi?id=310

Powered by Google App Engine
This is Rietveld 408576698